Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/gameengine/PyDoc/BL_ShapeActionActuator.py')
-rw-r--r--source/gameengine/PyDoc/BL_ShapeActionActuator.py63
1 files changed, 47 insertions, 16 deletions
diff --git a/source/gameengine/PyDoc/BL_ShapeActionActuator.py b/source/gameengine/PyDoc/BL_ShapeActionActuator.py
index a26b276a2da..209ff4e5580 100644
--- a/source/gameengine/PyDoc/BL_ShapeActionActuator.py
+++ b/source/gameengine/PyDoc/BL_ShapeActionActuator.py
@@ -4,10 +4,38 @@ from SCA_IActuator import *
class BL_ShapeActionActuator(SCA_IActuator):
"""
- ShapeAction Actuators apply an shape action to an mesh object.
+ ShapeAction Actuators apply an shape action to an mesh object.\
+
+ @ivar action: The name of the action to set as the current shape action.
+ @type action: string
+ @ivar start: Specifies the starting frame of the shape animation.
+ @type start: float
+ @type end: Specifies the ending frame of the shape animation.
+ @type end: float
+ @ivar blendin: Specifies the number of frames of animation to generate when making transitions between actions.
+ @type blendin: float
+ @ivar priority: Sets the priority of this actuator. Actuators will lower
+ priority numbers will override actuators with higher
+ numbers.
+ @type priority: integer
+ @ivar frame: Sets the current frame for the animation.
+ @type frame: float
+ @ivar property: Sets the property to be used in FromProp playback mode.
+ @type property: string
+ @ivar blendTime: Sets the internal frame timer. This property must be in
+ the range from 0.0 to blendin.
+ @type blendTime: float
+ @ivar type: The operation mode of the actuator.
+ KX_ACTIONACT_PLAY, KX_ACTIONACT_PROPERTY, KX_ACTIONACT_FLIPPER,
+ KX_ACTIONACT_LOOPSTOP, KX_ACTIONACT_LOOPEND
+ @type type: integer
+ @ivar frameProperty: The name of the property that is set to the current frame number.
+ @type frameProperty: string
+
"""
def setAction(action, reset = True):
"""
+ DEPRECATED: use the 'action' property
Sets the current action.
@param action: The name of the action to set as the current action.
@@ -21,6 +49,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setStart(start):
"""
+ DEPRECATED: use the 'start' property
Specifies the starting frame of the animation.
@param start: the starting frame of the animation
@@ -29,6 +58,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setEnd(end):
"""
+ DEPRECATED: use the 'end' property
Specifies the ending frame of the animation.
@param end: the ending frame of the animation
@@ -36,6 +66,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
"""
def setBlendin(blendin):
"""
+ DEPRECATED: use the 'blendin' property
Specifies the number of frames of animation to generate
when making transitions between actions.
@@ -45,6 +76,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setPriority(priority):
"""
+ DEPRECATED: use the 'priority' property
Sets the priority of this actuator.
@param priority: Specifies the new priority. Actuators will lower
@@ -54,6 +86,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
"""
def setFrame(frame):
"""
+ DEPRECATED: use the 'frame' property
Sets the current frame for the animation.
@param frame: Specifies the new current frame for the animation
@@ -62,6 +95,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setProperty(prop):
"""
+ DEPRECATED: use the 'property' property
Sets the property to be used in FromProp playback mode.
@param prop: the name of the property to use.
@@ -70,6 +104,7 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setBlendtime(blendtime):
"""
+ DEPRECATED: use the 'blendTime' property
Sets the internal frame timer.
Allows the script to directly modify the internal timer
@@ -81,37 +116,25 @@ class BL_ShapeActionActuator(SCA_IActuator):
def setType(mode):
"""
+ DEPRECATED: use the 'type' property
Sets the operation mode of the actuator
@param mode: KX_ACTIONACT_PLAY, KX_ACTIONACT_PROPERTY, KX_ACTIONACT_FLIPPER, KX_ACTIONACT_LOOPSTOP, KX_ACTIONACT_LOOPEND
@type mode: integer
"""
- def setContinue(cont):
- """
- Set the actions continue option True or False. see getContinue.
-
- @param cont: The continue option.
- @type cont: bool
- """
-
def getType():
"""
+ DEPRECATED: use the 'type' property
Returns the operation mode of the actuator
@rtype: integer
@return: KX_ACTIONACT_PLAY, KX_ACTIONACT_PROPERTY, KX_ACTIONACT_FLIPPER, KX_ACTIONACT_LOOPSTOP, KX_ACTIONACT_LOOPEND
"""
- def getContinue():
- """
- When True, the action will always play from where last left off, otherwise negative events to this actuator will reset it to its start frame.
-
- @rtype: bool
- """
-
def getAction():
"""
+ DEPRECATED: use the 'action' property
getAction() returns the name of the action associated with this actuator.
@rtype: string
@@ -119,24 +142,28 @@ class BL_ShapeActionActuator(SCA_IActuator):
def getStart():
"""
+ DEPRECATED: use the 'start' property
Returns the starting frame of the action.
@rtype: float
"""
def getEnd():
"""
+ DEPRECATED: use the 'end' property
Returns the last frame of the action.
@rtype: float
"""
def getBlendin():
"""
+ DEPRECATED: use the 'blendin' property
Returns the number of interpolation animation frames to be generated when this actuator is triggered.
@rtype: float
"""
def getPriority():
"""
+ DEPRECATED: use the 'priority' property
Returns the priority for this actuator. Actuators with lower Priority numbers will
override actuators with higher numbers.
@@ -144,23 +171,27 @@ class BL_ShapeActionActuator(SCA_IActuator):
"""
def getFrame():
"""
+ DEPRECATED: use the 'frame' property
Returns the current frame number.
@rtype: float
"""
def getProperty():
"""
+ DEPRECATED: use the 'property' property
Returns the name of the property to be used in FromProp mode.
@rtype: string
"""
def setFrameProperty(prop):
"""
+ DEPRECATED: use the 'frameProperty' property
@param prop: A string specifying the property of the object that will be updated with the action frame number.
@type prop: string
"""
def getFrameProperty():
"""
+ DEPRECATED: use the 'frameProperty' property
Returns the name of the property that is set to the current frame number.
@rtype: string